*** Purpose: Combine direct and ICU overflow deaths, multiply by VSLs to get benefits,
*** 			and plot benefits by age group

cap log close
clear

pause on

set scheme s2mono
graph set window fontface "Arial"


*** setup
*global ROOT "/Users/`c(username)'/Dropbox/Coronavirus/Public"

cd "$ROOT/Code"
local internal_data "$ROOT/Data"
local figs = "$ROOT"

local combine_channels = 1 // combine direct and overflow deaths
local plot = 1 // generate bar graph

local vsl_stems "mt epa" // consider both Murphy-Topel and age-invariant VSL distributions

*** Start

if `combine_channels' == 1 {

	use "`internal_data'/deaths_crowding_panel.dta", clear
	append using "`internal_data'/deaths_spread_panel.dta"

	sort age_cat days channel
	keep age_cat days channel deaths_hosp_* deaths_spread*
	
	collapse (sum) deaths*, by(days age_cat)
		
	*** Merge in VSLs
	merge m:1 age_cat using "`internal_data'/age_bracket_data.dta"
	keep if _merge == 3
	sort days age_cat 
	drop _merge
	
	* sum deaths across channels
	gen tot_deaths_0 = deaths_hosp_0 + deaths_spread_0
	gen tot_deaths_1 = deaths_hosp_1 + deaths_spread_1
	
	** compute total benefits under each vsl
	foreach v of local vsl_stems {
		gen benefits_`v' = (tot_deaths_0 - tot_deaths_1) * vsl_`v'
		sort age_cat days
	}

	** This panel now has deaths and benefits for 180 days x 9 age groups.
	save "`internal_data'/deaths_benefits_panel.dta", replace
}


if `plot' == 1 {

	*** Plot by age group
	use "`internal_data'/deaths_benefits_panel.dta", clear
		
	collapse (sum) benefits_mt tot_deaths*, by(age_cat)
	
	* add obs for total
	insob 1 _N, after
	replace age_cat = -1.5 if _n == _N
	summ benefits_mt, d
	gen benefits_mt_TOT = `r(sum)' if _n == _N
	
	* convert benefits to trillions
	replace benefits_mt = benefits_mt/1e12
	replace benefits_mt_TOT = benefits_mt_TOT/1e12
	
	graph twoway ///
		(bar benefits_mt_TOT age_cat, barwidth(0.5) color(green))  ///
		(bar benefits_mt age_cat, barwidth(0.5) color(green%50)) , ///
		ytitle("Trillions of US Dollars" " ", margin(vsmall) size(large)) ylabel(0(2)10 ,nogrid angle(horizontal)) ///
		xtitle("Age Group", margin(small) size(medlarge)) xlabel(-1.5 "{bf:Total}" 0 "0-9" 1 "10-19" 2 "20-29" 3 "30-39" 4 "40-49" 5 "50-59" 6 "60-69" 7 "70-79" 8 "80+", labsize(medsmall)) ///
		xscale(range(-1.5 8)) yscale(range(0(2)10)) ///
		graphregion(color(white)) bgcolor(white) plotregion(color(white)) ///
		legend(label(1 "Total Mortality Benefits of Social Distancing (tn $)") label(2 "Benefits by Age Group") cols(1) region(lcolor(none) color(none)) size(medium) position(0) bplacement(n)) ///
		xsize(12) ysize(8) 

	graph export "`figs'/fig3.pdf", replace

}


