*** Purpose: Compute ashenfelter and greenstone (2004) VSL in 2020$
*** 			and compute benefits in Table 2 with alternative VSLs
* Source: Ashenfelter and Greenstone (2004), FRED
* for GDPpc: https://fred.stlouisfed.org/series/A939RX0Q048SBEA
* for inflation: CPI all item index

cap log close
clear

local ag_vsl = 1.54e6 // estimated AG VSL
local ag_year = 1997 // year of AG estimate
local ag_cpi = 159.400 // CPI value in January of AG year (for inflation)
local ag_gdp_pc = 41532 // US GDP per capita in Q1 of AG year (Chained 2012 USD)

local gn_year = 2020
local gn_cpi = 258.820 // CPI value in January 2020
local gn_gdp_pc = 58392 // US GDP per capita in Q4 2019 (Chained 2012 USD)

local vsl_elas = 1 // elasticity of VSL with respect to GDP per capita

local epa_vsl = 11.5e6 // EPA VSL used to get original estimate
local original_benefits = 7.94e12 // original estimate of total benefits
local original_deaths = 1761951 // from Table 1


*** compute AG VSL in 2020
local ag_vsl_today = `ag_vsl' * (`gn_cpi'/`ag_cpi') * (1 + ((`gn_gdp_pc'-`ag_gdp_pc')/`ag_gdp_pc')*`vsl_elas')

di ((`gn_gdp_pc'-`ag_gdp_pc')/`ag_gdp_pc')*`vsl_elas'
di `ag_vsl_today'


******* Alternative measures of total benefits: 

*** row 4a: age-invariant VSL, using EPA VSL
di `original_deaths' * `epa_vsl'

*** row 4b: age-varying VSL, using Ashenfelter and Greenstone
* To obtain, scale total benefits by ratio of AG VSL (in 2020) to EPA VSL.
* Alternatively, use `ag_vsl_today' in place of `epa_vsl' in file 1, and run files 1-5.
di `original_benefits' * (`ag_vsl_today'/`epa_vsl')

*** row 4c: age-invariant AG VSL
di `original_deaths' * `ag_vsl_today'
